==> mobile_pos-0.6.0.tar.gz: lib/src/network/api_requests.dart <==
// ignore_for_file: use_build_context_synchronously

import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/app_info_model.dart';
import 'package:mobile_pos/src/models/keydetails.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/models/success_response.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/http_base.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/views/card_payment/card_balance.dart';
import 'package:mobile_pos/src/views/card_payment/card_failure_page.dart';
import 'package:mobile_pos/src/views/card_payment/card_success_page.dart';

import '../models/card_tx_response.dart';

class ApiRequests {
  static Future<bool> sendReceipts(context, phone, rrn) async {
    final payload = {
      "phone_number": phone.toString(),
      "rrn": rrn.toString(),
    };

    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Processing...',
            ));

    var response = await HttpBase.postRequest(payload, 'pdon/whatsapp_receipt');
    Navigator.pop(context);

    if (response == null && response == 'failed') {
      showSnack(context, 'Unable to sent receipt at the moment');
      return false;
    }

    if (response['status'] == 'success') {
      showSnack(context, 'Receipt was sent successfully');
      return true;
    }

    return false;
  }

  static Future<void> getCardBalance(
      BuildContext context, String cardPayload) async {
    final cardModel =
        CardTransactionResponseModel.fromJson(jsonDecode(cardPayload));
    Map<String, String> headerMap = {
      'x-device-model': 'K11',
      'x-brand': 'Horizonpay',
      'x-app-version': "1.0.0",
      'x-serial-no': "98211206905806",
      "Content-Type": "application/json"
    };
    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Processing...',
            ));
    Map<String, dynamic> nibssMap = cardModel.nibbsEMV!.toJson();
    nibssMap.update('ssl', (value) => 'true');

    var field52 = cardModel.nibbsEMV!.field52;
    if (!nibssMap.containsKey("field52")) {
      nibssMap.putIfAbsent('field52', () => '');
    } else {
      if (field52 == null) {
        nibssMap.update('field52', (value) => '');
      }

      if (field52 == 'null') {
        nibssMap.update('field52', (value) => '');
      }
    }

    var pinBlock = cardModel.nibbsEMV!.pinblock;
    if (!nibssMap.containsKey("pinblock")) {
      nibssMap.putIfAbsent('pinblock', () => '');
    } else {
      if (pinBlock == null) {
        nibssMap.update('pinblock', (value) => '');
      }

      if (pinBlock == 'null') {
        nibssMap.update('pinblock', (value) => '');
      }
    }
    final serializedMap = nibssMap.map((key, value) {
      return MapEntry(key, value);
    });

    var response = await HttpBase.postRequestJson(
        serializedMap, "http://46.101.123.218:5010/api/v1/card/checkBalance",
        isFullRoute: true, header: headerMap);
    Navigator.pop(context);
    try {
      if (response['status'] && response['resp'] == "00") {
        replaceRoute(
            context,
            CardBalance(
              maskedPan: cardModel.maskedPAN,
              balance: (double.tryParse(response['balance']) ?? 0.0) / 100,
            ));
        return;
      } else {
        replaceRoute(
            context,
            CardFailurePage(
              paymentType: PaymentType.checkBalance,
              reason: response['meaning'] ??
                  "something went wrong... please try again.",
            ));
        return;
      }
    } catch (ex) {
      replaceRoute(
          context,
          const CardFailurePage(
            paymentType: PaymentType.checkBalance,
            reason: "something went wrong... please try again.",
          ));
    }
  }

  static Future<void> processCard(
      BuildContext context, double amount, String cardData) async {
    // Mock success for staging
    // if (pluginConfig.isStaging) {
    //
    //   final res = RavenMPOSResponse();
    //
    //   pushRoute(
    //       context,
    //       CardSuccessPage(
    //         amount: amount,
    //         response: res,
    //       ));
    //   pluginConfig.onSuccess.call(res);
    //   return;
    // }

    final body = json.decode(cardData);

    final cardModel = CardTransactionResponseModel.fromJson(body);

    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Processing...',
            ));

    Map<String, dynamic> nibssMap = cardModel.nibbsEMV!.toJson();
    nibssMap.update('ssl', (value) => 'true');

    var field52 = cardModel.nibbsEMV!.field52;
    if (!nibssMap.containsKey("field52")) {
      nibssMap.putIfAbsent('field52', () => '');
    } else {
      if (field52 == null) {
        nibssMap.update('field52', (value) => '');
      }

      if (field52 == 'null') {
        nibssMap.update('field52', (value) => '');
      }
    }

    var pinBlock = cardModel.nibbsEMV!.pinblock;
    if (!nibssMap.containsKey("pinblock")) {
      nibssMap.putIfAbsent('pinblock', () => '');
    } else {
      if (pinBlock == null) {
        nibssMap.update('pinblock', (value) => '');
      }

      if (pinBlock == 'null') {
        nibssMap.update('pinblock', (value) => '');
      }
    }

    final payload = <String, dynamic>{};

    final serializedMap = nibssMap.map((key, value) {
      return MapEntry(key, value);
    });

    payload['card_data'] = serializedMap;
    payload['poseidon_serial_number'] = cardModel.ravenEMV!.pSerialNo ?? "";
    payload['app_profile'] = {
      "affiliate_app_name": pluginConfig.appInfo.appName,
      "affiliate_app_id": pluginConfig.appInfo.appId,
      "affiliate_app_email": pluginConfig.appInfo.appEmail,
      "poseidon_business_email": pluginConfig.customerInfo.email,
      "bvn": pluginConfig.customerInfo.bvn
    };

    // logData(jsonEncode(payload).toString());
    // logData('data logged');

    var response =
        await HttpBase.postRequestJson(payload, 'pdon/card_processing');
    Navigator.pop(context);
    //logData("Card processed");
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kNibbsError, message: 'Transaction failed to complete');
      replaceRoute(
          context,
          CardFailurePage(
            reason: error.message,
          ));
      pluginConfig.onError.call(error);
    } else {
      //Completes with a response
      if (response['data']['data']['resp'].toString() == '00') {
        final res = BankBoxResponse(data: Map.from(response));

        //success
        replaceRoute(
            context,
            CardSuccessPage(
              amount: amount,
              response: res,
              rrn: cardModel.nibbsEMV!.rrn,
            ));
        pluginConfig.onSuccess.call(res);
      } else {
        String? message;
        String? responseCode;

        try {
          message = refineMeaning(response);
          responseCode = response['data']['data']['resp'];
        } catch (e) {}

        //Unsuccessful
        final error = BankBoxException(
            code: kNibbsError,
            message:
                'Reason${message != null ? ': $responseCode / ${message.toLowerCase()}' : ''}');

        replaceRoute(
            context,
            CardFailurePage(
              reason: error.message,
              rrn: cardModel.nibbsEMV!.rrn,
            ));
        pluginConfig.onError.call(error);
      }
    }
  }

  static Future<bool> fetchAppInfoBool(context) async {
    bool value = false;

    if (aflliateInfo != null) {
      return value;
    }

    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Fetching keys...',
            ));

    final payload = {"affiliate_app_id": pluginConfig.appInfo.appId};

    var response =
        await HttpBase.postRequest(payload, 'pdon/affiliate_app_setting');

    //logData(response);

    Navigator.pop(context);

    if (response != null && response != 'failed') {
      if (response['data'] != null) {
        aflliateInfo =
            AflliateInfoModel.fromJson(response['data']['appsetting']);

        keyDetails = KeyDetails.fromJson(response['data']['keydetails']);

        if (keyDetails != null) {
          value = true;
          logData('Keys Acquired');
        }
      }
    }

    //logData(response);
    return value;
  }

  static Future<void> fetchAppInfo() async {
    if (aflliateInfo != null) return;

    final payload = {"affiliate_app_id": pluginConfig.appInfo.appId};

    // print(jsonEncode(payload));

    var response =
        await HttpBase.postRequest(payload, 'pdon/affiliate_app_setting');
    // print(response.toString());

    if (response != null && response != 'failed') {
      if (response['data'] != null) {
        aflliateInfo =
            AflliateInfoModel.fromJson(response['data']['appsetting']);

        keyDetails = KeyDetails.fromJson(response['data']['keydetails']);

        if (keyDetails != null) {
          logData('Keys Acquired');
        }
      }
    }

    //logData(response);
  }

  static Future<void> registerUser() async {
    final payload = pluginConfig.customerInfo.toJson();
    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    //logData(jsonEncode(payload));
    await HttpBase.postRequest(payload, 'pdon/register');
    //logData(response);
  }

  static Future<bool> updateUserDetails({
    required String busnessName,
    required String businessAddress,
    required String businessDescription,
    String? nin,
  }) async {
    final payload = {
      "busines_name": busnessName,
      "business_address": businessAddress,
      "business_description": businessDescription,
      "nin": nin ?? ''
    };
    payload["email"] = pluginConfig.customerInfo.email;
    payload["business_type"] = "poseidon";

    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    var response = await HttpBase.postRequest(payload, 'pdon/update');
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kUpdateUserError, message: 'User account update failed');
      pluginConfig.onError(error);
      return false;
    } else {
      return response['status'] == 'success';
    }
  }

  static Future<bool> requestTerminal({
    required int qty,
    String? state,
    String? lga,
    String? address,
    String? landmark,
    required DeliveryMethod deliveryMethod,
    required BuildContext context,
  }) async {
    final payload = {
      "quantity": qty.toString(),
      "delivery_state": state ?? 'pickup',
      "delivery_address": address ?? 'pickup',
      "delivery_lga": lga ?? 'pickup',
      "landmark": landmark ?? 'pickup',
      "purpose": "Collect business payments",
      "delivery_option": deliveryMethod.name
    };
    payload["poseidon_email"] = pluginConfig.customerInfo.email;
    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    var response = await HttpBase.postRequest(payload, 'pdon/request_bankbox');

    //print(response.toString());
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kRequestTerminalError, message: 'Terminal request failed');
      pluginConfig.onError(error);
      return false;
    } else {
      if (response['status'] == 'success') {
        return true;
      } else {
        showSnack(context,
            toBeginningOfSentenceCase(response['message'].toString()) ?? '');
        return false;
      }
    }
  }

  static Future<List<TerminalRequestModel>> getUserTerminalRequests() async {
    final payload = {
      "poseidon_email": pluginConfig.customerInfo.email,
      "affiliate_app_id": pluginConfig.appInfo.appId,
    };

    var response = await HttpBase.postRequest(payload, 'pdon/bankbox_request');
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kRequestTerminalError,
          message: 'Get user terminal requests failed');
      pluginConfig.onError(error);
      return [];
    } else {
      final list = (response['data'] as List)
          .map((e) => TerminalRequestModel.fromJson(e))
          .toList();
      return list;
    }
  }

  static Future<List<TerminalModel>> getUserTerminals() async {
    final payload = {
      "poseidon_email": pluginConfig.customerInfo.email,
      "affiliate_app_id": pluginConfig.appInfo.appId,
    };

    var response = await HttpBase.postRequest(payload, 'pdon/user_bankbox');
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kRequestTerminalError, message: 'Get user terminals failed');
      pluginConfig.onError(error);
      return [];
    } else {
      final list = (response['data'] as List)
          .map((e) => TerminalModel.fromJson(e))
          .toList();
      return list;
    }
  }

  static Future<bool> updateDeviceLabel({
    required String label,
    required String serialNumber,
    String? nin,
  }) async {
    final payload = {"label": label, "serial_number": serialNumber};
    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    var response = await HttpBase.postRequest(payload, 'pdon/update_bankbox');
    logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kDeviceLabelUpdateError,
          message: 'Could not update device label');
      pluginConfig.onError(error);
      return false;
    } else {
      return response['status'] == 'success';
    }
  }

  static Future<dynamic> getBluetoothDeviceInfo({
    required String serialNumber,
  }) async {
    final payload = {"serial_no": serialNumber};
    var response =
        await HttpBase.postRequest(payload, 'pdon/get_business_serial');
    logData(response);
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kDeviceLabelUpdateError,
          message: 'Could not update device label');
      pluginConfig.onError(error);
      return false;
    } else {
      if (response['status'] == "success") {
        return response['data'];
      }
      return false;
    }
  }

  static Future<void> updateBankBoxInjection({
    required String serialNumber,
  }) async {
    final payload = {"serial_no": serialNumber};
    var response = await HttpBase.postRequest(payload, 'pdon/update_injection');
    logData(response);
  }
}

==> mobile_pos-0.7.0.tar.gz: lib/src/network/api_requests.dart <==
// ignore_for_file: use_build_context_synchronously

import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/app_info_model.dart';
import 'package:mobile_pos/src/models/keydetails.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/models/success_response.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/http_base.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/views/card_payment/card_balance.dart';
import 'package:mobile_pos/src/views/card_payment/card_failure_page.dart';
import 'package:mobile_pos/src/views/card_payment/card_success_page.dart';

import '../models/card_tx_response.dart';

class ApiRequests {
  static Future<bool> sendReceipts(context, phone, rrn) async {
    final payload = {
      "phone_number": phone.toString(),
      "rrn": rrn.toString(),
    };

    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Processing...',
            ));

    var response = await HttpBase.postRequest(payload, 'pdon/whatsapp_receipt');
    Navigator.pop(context);

    if (response == null && response == 'failed') {
      showSnack(context, 'Unable to sent receipt at the moment');
      return false;
    }

    if (response['status'] == 'success') {
      showSnack(context, 'Receipt was sent successfully');
      return true;
    }

    return false;
  }

  static Future<void> getCardBalance(
      BuildContext context, String cardPayload) async {
    final cardModel =
        CardTransactionResponseModel.fromJson(jsonDecode(cardPayload));
    Map<String, String> headerMap = {
      'x-device-model': 'K11',
      'x-brand': 'Horizonpay',
      'x-app-version': "1.0.0",
      'x-serial-no': aflliateInfo?.serialNumber ?? "98211206905806",
      "Content-Type": "application/json"
    };
    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Processing...',
            ));
    Map<String, dynamic> nibssMap = cardModel.nibbsEMV!.toJson();
    nibssMap.update('ssl', (value) => 'true');

    var field52 = cardModel.nibbsEMV!.field52;
    if (!nibssMap.containsKey("field52")) {
      nibssMap.putIfAbsent('field52', () => '');
    } else {
      if (field52 == null) {
        nibssMap.update('field52', (value) => '');
      }

      if (field52 == 'null') {
        nibssMap.update('field52', (value) => '');
      }
    }

    var pinBlock = cardModel.nibbsEMV!.pinblock;
    if (!nibssMap.containsKey("pinblock")) {
      nibssMap.putIfAbsent('pinblock', () => '');
    } else {
      if (pinBlock == null) {
        nibssMap.update('pinblock', (value) => '');
      }

      if (pinBlock == 'null') {
        nibssMap.update('pinblock', (value) => '');
      }
    }
    final serializedMap = nibssMap.map((key, value) {
      return MapEntry(key, value);
    });

    var response = await HttpBase.postRequestJson(
        serializedMap, "http://46.101.123.218:5010/api/v1/card/checkBalance",
        isFullRoute: true, header: headerMap);
    Navigator.pop(context);
    try {
      if (response['status'] && response['resp'] == "00") {
        replaceRoute(
            context,
            CardBalance(
              maskedPan: cardModel.maskedPAN,
              balance: (double.tryParse(response['balance']) ?? 0.0) / 100,
            ));
        return;
      } else {
        replaceRoute(
            context,
            CardFailurePage(
              paymentType: PaymentType.checkBalance,
              reason: response['meaning'] ??
                  "something went wrong... please try again.",
            ));
        return;
      }
    } catch (ex) {
      replaceRoute(
          context,
          const CardFailurePage(
            paymentType: PaymentType.checkBalance,
            reason: "something went wrong... please try again.",
          ));
    }
  }

  static Future<void> processCard(
      BuildContext context, double amount, String cardData) async {
    // Mock success for staging
    // if (pluginConfig.isStaging) {
    //
    //   final res = RavenMPOSResponse();
    //
    //   pushRoute(
    //       context,
    //       CardSuccessPage(
    //         amount: amount,
    //         response: res,
    //       ));
    //   pluginConfig.onSuccess.call(res);
    //   return;
    // }

    final body = json.decode(cardData);

    final cardModel = CardTransactionResponseModel.fromJson(body);

    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Processing...',
            ));

    Map<String, dynamic> nibssMap = cardModel.nibbsEMV!.toJson();
    nibssMap.update('ssl', (value) => 'true');

    var field52 = cardModel.nibbsEMV!.field52;
    if (!nibssMap.containsKey("field52")) {
      nibssMap.putIfAbsent('field52', () => '');
    } else {
      if (field52 == null) {
        nibssMap.update('field52', (value) => '');
      }

      if (field52 == 'null') {
        nibssMap.update('field52', (value) => '');
      }
    }

    var pinBlock = cardModel.nibbsEMV!.pinblock;
    if (!nibssMap.containsKey("pinblock")) {
      nibssMap.putIfAbsent('pinblock', () => '');
    } else {
      if (pinBlock == null) {
        nibssMap.update('pinblock', (value) => '');
      }

      if (pinBlock == 'null') {
        nibssMap.update('pinblock', (value) => '');
      }
    }

    final payload = <String, dynamic>{};

    final serializedMap = nibssMap.map((key, value) {
      return MapEntry(key, value);
    });

    payload['card_data'] = serializedMap;
    payload['poseidon_serial_number'] = cardModel.ravenEMV!.pSerialNo ?? "";
    payload['app_profile'] = {
      "affiliate_app_name": pluginConfig.appInfo.appName,
      "affiliate_app_id": pluginConfig.appInfo.appId,
      "affiliate_app_email": pluginConfig.appInfo.appEmail,
      "poseidon_business_email": pluginConfig.customerInfo.email,
      "bvn": pluginConfig.customerInfo.bvn
    };

    // logData(jsonEncode(payload).toString());
    // logData('data logged');

    var response =
        await HttpBase.postRequestJson(payload, 'pdon/card_processing');
    Navigator.pop(context);
    //logData("Card processed");
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kNibbsError, message: 'Transaction failed to complete');
      replaceRoute(
          context,
          CardFailurePage(
            reason: error.message,
          ));
      pluginConfig.onError.call(error);
    } else {
      //Completes with a response
      if (response['data']['data']['resp'].toString() == '00') {
        final res = BankBoxResponse(data: Map.from(response));

        //success
        replaceRoute(
            context,
            CardSuccessPage(
              amount: amount,
              response: res,
              rrn: cardModel.nibbsEMV!.rrn,
            ));
        pluginConfig.onSuccess.call(res);
      } else {
        String? message;
        String? responseCode;

        try {
          message = refineMeaning(response);
          responseCode = response['data']['data']['resp'];
        } catch (e) {}

        //Unsuccessful
        final error = BankBoxException(
            code: kNibbsError,
            message:
                'Reason${message != null ? ': $responseCode / ${message.toLowerCase()}' : ''}');

        replaceRoute(
            context,
            CardFailurePage(
              reason: error.message,
              rrn: cardModel.nibbsEMV!.rrn,
            ));
        pluginConfig.onError.call(error);
      }
    }
  }

  static Future<bool> fetchAppInfoBool(context) async {
    bool value = false;

    if (aflliateInfo != null) {
      return value;
    }

    showDialog(
        barrierDismissible: false,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Fetching keys...',
            ));

    final payload = {"affiliate_app_id": pluginConfig.appInfo.appId};

    var response =
        await HttpBase.postRequest(payload, 'pdon/affiliate_app_setting');

    //logData(response);

    Navigator.pop(context);

    if (response != null && response != 'failed') {
      if (response['data'] != null) {
        aflliateInfo =
            AflliateInfoModel.fromJson(response['data']['appsetting']);

        keyDetails = KeyDetails.fromJson(response['data']['keydetails']);

        if (keyDetails != null) {
          value = true;
          logData('Keys Acquired');
        }
      }
    }

    //logData(response);
    return value;
  }

  static Future<void> fetchAppInfo() async {
    if (aflliateInfo != null) return;

    final payload = {"affiliate_app_id": pluginConfig.appInfo.appId};

    // print(jsonEncode(payload));

    var response =
        await HttpBase.postRequest(payload, 'pdon/affiliate_app_setting');
    // print(response.toString());

    if (response != null && response != 'failed') {
      if (response['data'] != null) {
        aflliateInfo =
            AflliateInfoModel.fromJson(response['data']['appsetting']);

        keyDetails = KeyDetails.fromJson(response['data']['keydetails']);

        if (keyDetails != null) {
          logData('Keys Acquired');
        }
      }
    }

    //logData(response);
  }

  static Future<void> registerUser() async {
    final payload = pluginConfig.customerInfo.toJson();
    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    //logData(jsonEncode(payload));
    await HttpBase.postRequest(payload, 'pdon/register');
    //logData(response);
  }

  static Future<bool> updateUserDetails({
    required String busnessName,
    required String businessAddress,
    required String businessDescription,
    String? nin,
  }) async {
    final payload = {
      "busines_name": busnessName,
      "business_address": businessAddress,
      "business_description": businessDescription,
      "nin": nin ?? ''
    };
    payload["email"] = pluginConfig.customerInfo.email;
    payload["business_type"] = "poseidon";

    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    var response = await HttpBase.postRequest(payload, 'pdon/update');
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kUpdateUserError, message: 'User account update failed');
      pluginConfig.onError(error);
      return false;
    } else {
      return response['status'] == 'success';
    }
  }

  static Future<bool> requestTerminal({
    required int qty,
    String? state,
    String? lga,
    String? address,
    String? landmark,
    required DeliveryMethod deliveryMethod,
    required BuildContext context,
  }) async {
    final payload = {
      "quantity": qty.toString(),
      "delivery_state": state ?? 'pickup',
      "delivery_address": address ?? 'pickup',
      "delivery_lga": lga ?? 'pickup',
      "landmark": landmark ?? 'pickup',
      "purpose": "Collect business payments",
      "delivery_option": deliveryMethod.name
    };
    payload["poseidon_email"] = pluginConfig.customerInfo.email;
    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    var response = await HttpBase.postRequest(payload, 'pdon/request_bankbox');

    //print(response.toString());
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kRequestTerminalError, message: 'Terminal request failed');
      pluginConfig.onError(error);
      return false;
    } else {
      if (response['status'] == 'success') {
        return true;
      } else {
        showSnack(context,
            toBeginningOfSentenceCase(response['message'].toString()) ?? '');
        return false;
      }
    }
  }

  static Future<List<TerminalRequestModel>> getUserTerminalRequests() async {
    final payload = {
      "poseidon_email": pluginConfig.customerInfo.email,
      "affiliate_app_id": pluginConfig.appInfo.appId,
    };

    var response = await HttpBase.postRequest(payload, 'pdon/bankbox_request');
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kRequestTerminalError,
          message: 'Get user terminal requests failed');
      pluginConfig.onError(error);
      return [];
    } else {
      final list = (response['data'] as List)
          .map((e) => TerminalRequestModel.fromJson(e))
          .toList();
      return list;
    }
  }

  static Future<List<TerminalModel>> getUserTerminals() async {
    final payload = {
      "poseidon_email": pluginConfig.customerInfo.email,
      "affiliate_app_id": pluginConfig.appInfo.appId,
    };

    var response = await HttpBase.postRequest(payload, 'pdon/user_bankbox');
    //logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kRequestTerminalError, message: 'Get user terminals failed');
      pluginConfig.onError(error);
      return [];
    } else {
      final list = (response['data'] as List)
          .map((e) => TerminalModel.fromJson(e))
          .toList();
      return list;
    }
  }

  static Future<bool> updateDeviceLabel({
    required String label,
    required String serialNumber,
    String? nin,
  }) async {
    final payload = {"label": label, "serial_number": serialNumber};
    payload["affiliate_app_id"] = pluginConfig.appInfo.appId;
    var response = await HttpBase.postRequest(payload, 'pdon/update_bankbox');
    logData(response);

    //failed
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kDeviceLabelUpdateError,
          message: 'Could not update device label');
      pluginConfig.onError(error);
      return false;
    } else {
      return response['status'] == 'success';
    }
  }

  static Future<dynamic> getBluetoothDeviceInfo({
    required String serialNumber,
  }) async {
    final payload = {"serial_no": serialNumber};
    var response =
        await HttpBase.postRequest(payload, 'pdon/get_business_serial');
    logData(response);
    if (response == 'failed' || response == null) {
      final error = BankBoxException(
          code: kDeviceLabelUpdateError,
          message: 'Could not update device label');
      pluginConfig.onError(error);
      return false;
    } else {
      if (response['status'] == "success") {
        return response['data'];
      }
      return false;
    }
  }

  static Future<void> updateBankBoxInjection({
    required String serialNumber,
  }) async {
    final payload = {"serial_no": serialNumber};
    var response = await HttpBase.postRequest(payload, 'pdon/update_injection');
    logData(response);
  }

  static Future<dynamic> getNetworkStates() async {
    var response = await HttpBase.getRequestWithHeader(
        {}, '${HttpBase.hostUrl}pdon/network_stability_summary');

    if (response == 'failed' || response == null) {
      return false;
    } else {
      if (response['status'] == "success") {
        return response['data'];
      }
      return false;
    }
  }
}
